@@ -58,4 +58,10 @@ class Settings(six.with_metaclass(SettingsBase)):
     to the name of the class.
 
     """
-    pass
+    @classmethod
+    def pre_setup(cls):
+        pass
+
+    @classmethod
+    def post_setup(cls):
+        pass
