@@ -1,9 +1,11 @@
 import os
 import uuid
-from configurations import Settings
+from configurations import Settings, pristinemethod
 
 
 class Test(Settings):
+    DEBUG = True
+
     SITE_ID = 1
 
     SECRET_KEY = str(uuid.uuid4())
@@ -28,19 +30,33 @@ class Test(Settings):
 
     TEST_RUNNER = 'discover_runner.DiscoverRunner'
 
-    TEST_SETTING = True
-
-    _SOMETHING = 'YEAH'
-
-    DEBUG = True
-
-    @property
-    def LALA(self):
-        return 1
-
-    def LALA2(self):
-        return 1
-
     def TEMPLATE_CONTEXT_PROCESSORS(self):
         return Settings.TEMPLATE_CONTEXT_PROCESSORS + (
             'configurations.tests.settings.base.test_callback',)
+
+    ATTRIBUTE_SETTING = True
+
+    _PRIVATE_SETTING = 'ryan'
+
+    @property
+    def PROPERTY_SETTING(self):
+        return 1
+
+    def METHOD_SETTING(self):
+        return 2
+
+    LAMBDA_SETTING = lambda self: 3
+
+    PRISTINE_LAMBDA_SETTING = pristinemethod(lambda: 4)
+
+    @pristinemethod
+    def PRISTINE_FUNCTION_SETTING():
+        return 5
+
+    @classmethod
+    def pre_setup(cls):
+        cls.PRE_SETUP_TEST_SETTING = 6
+
+    @classmethod
+    def post_setup(cls):
+        cls.POST_SETUP_TEST_SETTING = 7
